# NeuroLang

[![Codacy Badge](https://api.codacy.com/project/badge/Grade/ccd82a09587348bc803b986fe65c7aee)](https://www.codacy.com?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=NeuroLang/NeuroLang&amp;utm_campaign=Badge_Grade) [![Codacy Badge](https://api.codacy.com/project/badge/Coverage/ccd82a09587348bc803b986fe65c7aee)](https://www.codacy.com?utm_source=github.com&utm_medium=referral&utm_content=NeuroLang/NeuroLang&utm_campaign=Badge_Coverage)

[![Maintainability](https://api.codeclimate.com/v1/badges/dc08b264f2be98d9a9e2/maintainability)](https://codeclimate.com/repos/5d2c5d18aaf970014e004cd8/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/dc08b264f2be98d9a9e2/test_coverage)](https://codeclimate.com/repos/5d2c5d18aaf970014e004cd8/test_coverage)


Neurolang enables the analysis of NeuroImaging data through probabilistic logic programming. It seamlessly allow to combine, images, databases, and ontologies within a single framework.


Important links
===============
- Official source code repo: https://github.com/Neurolang/Neurolang/
- HTML documentation (stable release): http://neurolang.github.io/
- HTML documentation (dev release): http://neurolang.github.io/dev

